@@ -11,6 +11,7 @@ from tqdm import tqdm
 
 logger = logging.getLogger()
 unix_month = 2678400000
+one_hour = 3600 * 1000
 
 
 class LoadDataKline:
@@ -105,12 +106,15 @@ class LoadTradeKline:
                 pbr.set_description(sym)
                 self.load(sym, *args, **kwargs)
 
-    def load(self, symbol, unix_start, unix_end, *args, **kwargs):
+    def load_bak(self, symbol, unix_start, unix_end, *args, **kwargs):
         one_hour = 3600 * 1000
         since = unix_start
         previous_trade_id = None
         while since < unix_end:
             try:
+                params = {
+                    'end_time': int(end_time / 1000),
+                }
                 trades = self.exchange.fetch_trades(symbol, since, limit=1000)
 
                 if len(trades) == 0:
@@ -142,8 +146,7 @@ class LoadTradeKline:
                 print(type(e).__name__, str(e))
                 self.exchange.sleep(10000)
 
-    def load_csv(self, symbol, unix_start, unix_end, *args, **kwargs):
-        one_hour = 3600 * 1000
+    def load(self, symbol, unix_start, unix_end, *args, **kwargs):
         since = unix_start
         previous_trade_id = None
         result = []
